========
Zucchini
========


.. image:: https://img.shields.io/pypi/v/zucchini.svg
        :target: https://pypi.python.org/pypi/zucchini

.. image:: https://img.shields.io/travis/zucchini/zucchini.svg
        :target: https://travis-ci.org/zucchini/zucchini

.. image:: https://readthedocs.org/projects/zucchini/badge/?version=latest
        :target: https://zucchini.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/zucchini/zucchini/shield.svg
     :target: https://pyup.io/repos/github/zucchini/zucchini/
     :alt: Updates


Zucchini is an automatic grader tool for use in grading programming assignments.


* Free software: Apache Software License 2.0
* Documentation: https://zucchini.readthedocs.io.


Getting Started with Development
--------------------------------

After cloning this repo and installing virtualenv, run

::

   $ virtualenv -p python3 venv
   $ . venv/bin/activate
   $ pip install -r requirements.txt
   $ pip install -r requirements_dev.txt
   $ zucc --help

Features
--------

* TODO

Credits
---------

* TODO
